@@ -55,34 +55,49 @@ db_hash_by_id (BablHashTable *htab, Babl *item)
   return babl_hash_by_int (htab, item->instance.id);
 }
 
+static int
+each_free (Babl *data,
+           void *foo)
+{
+  babl_free (data);
+  return 0;
+}
+
+static int
+babl_db_destroy (void *data)
+{
+  BablDb *db = data;
+  babl_assert (db);
+
+  babl_db_each (db, each_free, NULL);
+  babl_mutex_destroy (db->mutex);
+  babl_free (db->name_hash);
+  babl_free (db->id_hash);
+  babl_free (db->babl_list);
+  return 0;
+}
+
 BablDb *
 babl_db_init (void)
 {
   BablDb *db = babl_calloc (sizeof (BablDb), 1);
+  babl_set_destructor (db, babl_db_destroy);
 
   db->name_hash = babl_hash_table_init (db_hash_by_name, db_find_by_name);
   db->id_hash = babl_hash_table_init (db_hash_by_id, db_find_by_id);
-  db->babl_list = babl_list_init ();
+  db->babl_list = babl_list_init_with_size (512);
+  db->mutex = babl_mutex_new ();
 
   return db;
 }
 
-void
-babl_db_destroy (BablDb *db)
-{
-  babl_assert (db);
-
-  babl_hash_table_destroy (db->name_hash);
-  babl_hash_table_destroy (db->id_hash);
-  babl_list_destroy (db->babl_list);
-  babl_free (db);
-}
 
 Babl *
 babl_db_find (BablDb     *db,
               const char *name)
 {
-  return babl_hash_table_find (db->name_hash, babl_hash_by_str (db->name_hash, name), (void *) name);
+  return babl_hash_table_find (db->name_hash, babl_hash_by_str (db->name_hash, name),
+                              NULL, (void *) name);
 }
 
 int
@@ -95,6 +110,7 @@ Babl *
 babl_db_insert (BablDb *db,
                 Babl   *item)
 {
+  babl_mutex_lock (db->mutex);
   if (item->instance.id)
     babl_hash_table_insert (db->id_hash, item);
   babl_hash_table_insert (db->name_hash, item);
@@ -103,8 +119,8 @@ babl_db_insert (BablDb *db,
   /* this point all registered items pass through, a nice
   * place to brand them with where the item came from. */
   item->instance.creator = babl_extender ();
+  babl_mutex_unlock (db->mutex);
   return item;
-
 }
 
 void
@@ -121,22 +137,29 @@ babl_db_exist (BablDb     *db,
                int        id,
                const char *name)
 {
+  Babl *ret;
   if (id)
-    return babl_hash_table_find (db->id_hash, babl_hash_by_int (db->id_hash, id), &id);
-  return babl_hash_table_find (db->name_hash, babl_hash_by_str (db->name_hash, name), (void *) name);
+    ret = babl_hash_table_find (db->id_hash, babl_hash_by_int (db->id_hash, id), NULL, &id);
+  else 
+    ret = babl_hash_table_find (db->name_hash, babl_hash_by_str (db->name_hash, name), NULL, (void *) name);
+  return ret;
 }
 
 Babl *
 babl_db_exist_by_id (BablDb *db,
                      int    id)
 {
-  return  babl_hash_table_find (db->id_hash, babl_hash_by_int (db->id_hash, id),  &id);
+  Babl *ret;
+  ret = babl_hash_table_find (db->id_hash, babl_hash_by_int (db->id_hash, id), NULL, &id);
+  return ret;
 }
 
 Babl *
 babl_db_exist_by_name (BablDb     *db,
                        const char *name)
 {
-  return  babl_hash_table_find (db->name_hash, babl_hash_by_str (db->name_hash, name), (void *) name);
+  Babl *ret;
+  ret = babl_hash_table_find (db->name_hash, babl_hash_by_str (db->name_hash, name),
+                              NULL, (void *) name);
+  return ret;
 }
-
