@@ -58,14 +58,14 @@ int babl_hmpf_on_name_lookups = 0;
 #include <sys/types.h>
 #include <unistd.h>
 
-void
+int
 babl_backtrack (void)
 {
   char buf[512];
 
   sprintf (buf, "echo bt>/tmp/babl.gdb;"
-           "gdb -q --batch -x /tmp/babl.gdb --pid=%i 2>/dev/null", getpid ());
-  system (buf);
+           "gdb -q --batch -x /tmp/babl.gdb --pid=%i | grep 'in ''babl_die' -A40", getpid ());
+  return system (buf);
 }
 
 void
@@ -75,60 +75,30 @@ babl_die (void)
   exit (-1);
 }
 
-long babl_total_usecs = 0;
 
-long
-babl_process (Babl *babl,
-              void *source,
-              void *destination,
-              long  n)
-{
-  babl_assert (babl);
-  babl_assert (source);
-  babl_assert (destination);
-  babl_assert (BABL_IS_BABL (babl));
-  if (n == 0)
-    return 0;
-  babl_assert (n > 0);
-
-  /* matches all conversion classes */
-  if (babl->class_type >= BABL_CONVERSION &&
-      babl->class_type <= BABL_CONVERSION_PLANAR)
-    return babl_conversion_process (babl, source, destination, n);
-
-  if (babl->class_type == BABL_FISH ||
-      babl->class_type == BABL_FISH_REFERENCE ||
-      babl->class_type == BABL_FISH_PATH ||
-      babl->class_type == BABL_FISH_SIMPLE)
-    {
-      long ret;
-      long ticks = babl_ticks ();
-      ret = babl_fish_process (babl, source, destination, n);
-
-      ticks -= babl_ticks ();
-      ticks *= -1L;
-
-      babl_total_usecs += ticks;
-      babl->fish.usecs += ticks;
-      babl->fish.processings++;
-      babl->fish.pixels += ret;
-      return ret;
-    }
-
-  babl_fatal ("eek");
-  return -1;
-}
+BablMutex *babl_format_mutex;
+#if BABL_DEBUG_MEM
+BablMutex *babl_debug_mutex;
+#endif
 
 void
 babl_internal_init (void)
 {
   babl_set_malloc (malloc);
   babl_set_free (free);
+  babl_format_mutex = babl_mutex_new ();
+#if BABL_DEBUG_MEM
+  babl_debug_mutex = babl_mutex_new ();
+#endif
 }
 
 void
 babl_internal_destroy (void)
 {
+  babl_mutex_destroy (babl_format_mutex);
+#if BABL_DEBUG_MEM
+  babl_mutex_destroy (babl_debug_mutex);
+#endif
 }
 
 
