@@ -36,26 +36,21 @@ babl_list_init (void);
 BablList *
 babl_list_init_with_size (int initial_size);
 
-void
-babl_list_destroy (BablList *list);
-
 int
 babl_list_size (BablList *list);
 
-inline void
+void
 babl_list_insert_last (BablList *list,
                        Babl     *item);
 
-inline void
+void
 babl_list_remove_last (BablList *list);
 
-inline Babl *
-babl_list_get_first (BablList *list);
+#define babl_list_get_first(list) (list->items[0])
+#define babl_list_get_last(list)  (list->items[list->count-1])
+#define babl_list_size(list)      (list->count)
 
-inline Babl *
-babl_list_get_last (BablList *list);
-
-inline void
+void
 babl_list_copy (BablList *from,
                 BablList *to);
 
