@@ -17,6 +17,7 @@
  */
 
 #include "config.h"
+#include <stdint.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -40,12 +41,14 @@ babl_set_free (BablFreeFunc free_function)
   free_f = free_function;
 }
 
-static char *signature = "So long and thanks for all the fish.";
+static char *signature = "babl-memory";
+static char *freed = "So long and thanks for all the fish.";
 
 typedef struct
 {
   char  *signature;
   size_t size;
+  int  (*destructor)(void *ptr);
 } BablAllocInfo;
 
 #define BABL_ALIGN     16
@@ -53,6 +56,8 @@ typedef struct
 #define BAI(ptr)       ((BablAllocInfo *) *((void **) ptr - 1))
 #define IS_BAI(ptr)    (BAI (ptr)->signature == signature)
 
+#if BABL_DEBUG_MEM
+
 /* runtime statistics: */
 static int mallocs  = 0;
 static int frees    = 0;
@@ -71,6 +76,8 @@ mem_stats (void)
   return buf;
 }
 
+#endif
+
 static void
 functions_sanity (void)
 {
@@ -106,16 +113,31 @@ babl_malloc (size_t size)
   if (!ret)
     babl_fatal ("args=(%i): failed", size);
 
-  offset = BABL_ALIGN - ((unsigned int) ret + BABL_ALLOC) % BABL_ALIGN;
+  offset = BABL_ALIGN - ((uintptr_t) ret + BABL_ALLOC) % BABL_ALIGN;
   ret = ret + BABL_ALLOC + offset;
 
   *((void **) ret - 1) = ret - BABL_ALLOC - offset;
   BAI (ret)->signature = signature;
   BAI (ret)->size      = size;
+  BAI (ret)->destructor = NULL;
+#if BABL_DEBUG_MEM
+  babl_mutex_lock (babl_debug_mutex); 
   mallocs++;
+  babl_mutex_unlock (babl_debug_mutex); 
+#endif
   return (void *) (ret);
 }
 
+/* set a callback to be called when the segment is freed.
+ */
+void
+babl_set_destructor (void  *ptr,
+                     int (*destructor)(void *ptr))
+{
+  babl_assert (IS_BAI (ptr));
+  BAI(ptr)->destructor = destructor;
+}
+
 /* Create a duplicate allocation of the same size, note
  * that the exact location of the allocation needs to be
  * passed.
@@ -130,8 +152,12 @@ babl_dup (void *ptr)
   ret = babl_malloc (BAI (ptr)->size);
   memcpy (ret, ptr, BAI (ptr)->size);
 
+#if BABL_DEBUG_MEM
+  babl_mutex_lock (babl_debug_mutex); 
   dups++;
   mallocs--;
+  babl_mutex_unlock (babl_debug_mutex); 
+#endif
   return NULL;
 }
 
@@ -145,57 +171,28 @@ void
 babl_free (void *ptr,
            ...)
 {
-  /* XXX:
-   *  Extra logic to make the bookeeping of BablImage cached
-   *  templates work out correctly, by using a babl_image_destroy
-   *  and custom destroy functions for babl_format this would be
-   *  avoided and the extra overhead not needed for non image/format
-   *  typed allocations.
-   */
-  if (BABL_IS_BABL (ptr))
-    {
-      switch (BABL (ptr)->instance.class_type)
-        {
-        case BABL_IMAGE:
-          {
-            BablFormat *format = BABL(ptr)->image.format;
-            if (format)
-              {
-                if (format->image_template == NULL)
-                  {
-                    format->image_template = ptr;
-                    return;
-                  }
-                else
-                  {
-                  }
-              }
-          }
-          break;
-        case BABL_FORMAT:
-          {
-            BablFormat *format = ptr;
-            if (format->image_template != NULL)
-              {
-                BAI (format->image_template)->signature = NULL;
-                free_f (BAI (format->image_template));
-                frees++;
-              }
-            format->image_template = NULL;
-          }
-          break;
-          default:
-          break;
-        }
-    }
+  functions_sanity ();
   if (!ptr)
     return;
   if (!IS_BAI (ptr))
-    babl_fatal ("memory not allocated by babl allocator");
-  functions_sanity ();
-  BAI (ptr)->signature = NULL;
+    {
+      #define IS_BAI(ptr)    (BAI (ptr)->signature == signature)
+      if (freed)
+        babl_fatal ("\nbabl:double free detected\n------------------------");
+      babl_fatal ("memory not allocated by babl allocator");
+    }
+
+  if (BAI (ptr)->destructor)
+    if (BAI (ptr)->destructor (ptr))
+      return; /* bail out on non 0 return from destructor */
+
+  BAI (ptr)->signature = freed;
   free_f (BAI (ptr));
+#if BABL_DEBUG_MEM
+  babl_mutex_lock (babl_debug_mutex); 
   frees++;
+  babl_mutex_unlock (babl_debug_mutex); 
+#endif
 }
 
 /* reallocate allocation to be in size instead, contents of
@@ -235,8 +232,14 @@ babl_realloc (void  *ptr,
       ret = babl_malloc (size);
 #endif
       memcpy (ret, ptr, babl_sizeof (ptr));
+      BAI (ret)->destructor = BAI (ptr)->destructor;
+      BAI (ptr)->destructor = NULL;
       babl_free (ptr);
+#if BABL_DEBUG_MEM
+      babl_mutex_lock (babl_debug_mutex); 
       reallocs++;
+      babl_mutex_unlock (babl_debug_mutex); 
+#endif
       return ret;
     }
 
@@ -258,8 +261,12 @@ babl_calloc (size_t nmemb,
 
   memset (ret, 0, nmemb * size);
 
+#if BABL_DEBUG_MEM
+  babl_mutex_lock (babl_debug_mutex); 
   callocs++;
   mallocs--;
+  babl_mutex_unlock (babl_debug_mutex); 
+#endif
   return ret;
 }
 
@@ -285,8 +292,12 @@ babl_strdup (const char *s)
     babl_log ("args=(%s): failed", s);
   strcpy (ret, s);
 
+#if BABL_DEBUG_MEM
+  babl_mutex_lock (babl_debug_mutex); 
   strdups++;
   mallocs--;
+  babl_mutex_unlock (babl_debug_mutex); 
+#endif
   return ret;
 }
 
@@ -331,6 +342,7 @@ babl_strcat (char       *dest,
   return ret;
 }
 
+#if BABL_DEBUG_MEM
 /* performs a sanity check on memory, (checks if number of
  * allocations and frees on babl memory evens out to zero).
  */
@@ -347,3 +359,4 @@ babl_memory_sanity (void)
     }
   return 0;
 }
+#endif
