@@ -16,10 +16,12 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include <string.h>
 #include <assert.h>
 
 #include "babl.h"
+#include "babl-classes.h"
 #include "babl-ids.h"
 #include "babl-base.h"
 
@@ -65,15 +67,15 @@ babl_base_type_float (void)
     NULL);
 
   babl_conversion_new (
-    babl_type_id (BABL_FLOAT),
-    babl_type_id (BABL_DOUBLE),
+    babl_type_from_id (BABL_FLOAT),
+    babl_type_from_id (BABL_DOUBLE),
     "plane", convert_float_double,
     NULL
   );
 
   babl_conversion_new (
-    babl_type_id (BABL_DOUBLE),
-    babl_type_id (BABL_FLOAT),
+    babl_type_from_id (BABL_DOUBLE),
+    babl_type_from_id (BABL_FLOAT),
     "plane", convert_double_float,
     NULL
   );
