@@ -16,6 +16,7 @@
  * <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include "babl-internal.h"
 
 #define PIXELS    5
@@ -30,7 +31,7 @@ float rgb_buf     [PIXELS * 3];
 static int
 test (void)
 {
-  Babl *fish;
+  const Babl *fish;
   int   i;
   int   OK = 1;
 
@@ -76,7 +77,7 @@ main (int    argc,
   babl_init ();
   if (test ())
     return -1;
-  babl_destroy ();
+  babl_exit ();
   return 0;
 }
 
