@@ -1,3 +1,4 @@
+#include "config.h"
 #include <math.h>
 #include "babl-internal.h"
 
@@ -19,9 +20,9 @@ int main (void)
   babl_init ();
 
   babl_set_extender (babl_extension_quiet_log ());
-  babl_type_each (type_check, NULL);
+  babl_type_class_for_each (type_check, NULL);
 
-  babl_destroy ();
+  babl_exit ();
 
   return !OK;
 }
